[Secure-testing-commits] r34072 - bin lib/python

Salvatore Bonaccorso carnil at moszumanska.debian.org
Tue May 5 04:29:58 UTC 2015


Author: carnil
Date: 2015-05-05 04:29:58 +0000 (Tue, 05 May 2015)
New Revision: 34072

Modified:
   bin/tracker_service.py
   lib/python/security_db.py
Log:
Adjust some places where jessie -> stretch as testing release was missing

Modified: bin/tracker_service.py
===================================================================
--- bin/tracker_service.py	2015-05-05 04:04:21 UTC (rev 34071)
+++ bin/tracker_service.py	2015-05-05 04:29:58 UTC (rev 34072)
@@ -875,7 +875,7 @@
                 (SELECT testing.version_id < stable.version_id
                  FROM source_packages AS testing, source_packages AS stable
                  WHERE testing.name = testing_status.package
-                 AND testing.release = 'jessie'
+                 AND testing.release = 'stretch'
                  AND testing.subrelease = ''
                  AND testing.archive = testing_status.section
                  AND stable.name = testing_status.package

Modified: lib/python/security_db.py
===================================================================
--- lib/python/security_db.py	2015-05-05 04:04:21 UTC (rev 34071)
+++ lib/python/security_db.py	2015-05-05 04:29:58 UTC (rev 34072)
@@ -989,7 +989,7 @@
         """Calculate vulnerable packages.
 
         To each package note, a release-specific vulnerability status
-        is attached.  Currently, only jessie/testing is processed.
+        is attached.  Currently, only stretch/testing is processed.
 
         Returns a list strings describing inconsistencies.
         """
@@ -1005,7 +1005,7 @@
         # The following does not work because stable->security ->
         # testing -> unstable propagation is no longer available.
         if False:
             # Ignore jessie/testing because stable issues may be
             # fast-tracked into testing, bypassing unstable.
             for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \
                     in list(cursor.execute(
@@ -1013,7 +1013,7 @@
             a.fixed_version, b.fixed_version
             FROM package_notes a, package_notes b
             WHERE a.bug_name = b.bug_name AND a.package = b.package
-            AND a.release = '' AND b.release NOT IN ('', 'jessie')
+            AND a.release = '' AND b.release NOT IN ('', 'stretch')
             AND a.fixed_version IS NOT NULL
             AND a.fixed_version_id < b.fixed_version_id""")):
                 b = bugs.BugFromDB(cursor, bug_name)
@@ -1005,7 +1005,7 @@
         # testing -> unstable propagation is no longer available.
         if False:
-            # Ignore jessie/testing because stable issues may be
+            # Ignore stretch/testing because stable issues may be
             # fast-tracked into testing, bypassing unstable.
             for (bug_name, pkg_name, rel, unstable_ver, rel_ver) \




More information about the Secure-testing-commits mailing list